//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraInfo](index.md)/[tsumo](tsumo.md)

# tsumo

[common]\
abstract val [tsumo](tsumo.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否自摸
